/**************************************************************************
* fisharium.h: Fisharium by Tim Park
**************************************************************************/
// Convenience defines
#define BG_NOCHANGE	-1
#define BG_BLACK	0
#define BG_RED		BACKGROUND_RED
#define BG_GREEN	BACKGROUND_GREEN
#define BG_BLUE		BACKGROUND_BLUE
#define BG_YELLOW	(BACKGROUND_RED | BACKGROUND_GREEN)
#define BG_PURPLE	(BACKGROUND_RED | BACKGROUND_BLUE)
#define BG_CYAN		(BACKGROUND_GREEN | BACKGROUND_BLUE)
#define BG_WHITE	(BACKGROUND_RED | BACKGROUND_GREEN | BACKGROUND_BLUE)

#define FG_NOCHANGE	-1
#define FG_BLACK	0
#define FG_RED		FOREGROUND_RED
#define FG_GREEN	FOREGROUND_GREEN
#define FG_BLUE		FOREGROUND_BLUE
#define FG_YELLOW	(FOREGROUND_RED | FOREGROUND_GREEN)
#define FG_PURPLE	(FOREGROUND_RED | FOREGROUND_BLUE)
#define FG_CYAN		(FOREGROUND_GREEN | FOREGROUND_BLUE)
#define FG_WHITE	(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_BLUE)

#define FG_LBLACK	(FOREGROUND_INTENSITY)
#define FG_LRED		(FOREGROUND_RED | FOREGROUND_INTENSITY)
#define FG_LGREEN	(FOREGROUND_GREEN | FOREGROUND_INTENSITY)
#define FG_LBLUE	(FOREGROUND_BLUE | FOREGROUND_INTENSITY)
#define FG_LYELLOW	(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_INTENSITY)
#define FG_LPURPLE	(FOREGROUND_RED | FOREGROUND_BLUE | FOREGROUND_INTENSITY)
#define FG_LCYAN	(FOREGROUND_GREEN | FOREGROUND_BLUE | FOREGROUND_INTENSITY)
#define FG_LWHITE	(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_BLUE | FOREGROUND_INTENSITY)

// Mode defines
#define DISPLAY 0
#define OPTIONS 1
#define PLAY 2
#define TORMENT 3

// Display defines
#define COLOUR 0
#define BLACKANDWHITE 1
#define DISCO 2
#define WINDOWS 3
#define MATRIX 4

// Play defines
#define NOTHING 0
#define FEED 1
#define SPEAK 2
#define PET 3
#define DANCE 4
#define SLEEP 5
#define PLAYDEAD 6

// Torment defines
//#define NOTHING 0
#define HEAT 1
#define COLD 2
#define POISON 3
#define LOWERWATER 4

// Fish state defines
#define RESTING 0
#define MOVING 1
#define TURNING 2 //for fish
#define LEFT 0
#define RIGHT 1

// Various config stuff
struct conf {
	short uimode;		//display, etc.
	short dispmode;		//colour, b&w, etc
	short tormentmode;	//heat, cold, yada yada
	short playmode, actiontime;	//play time
	short sound, music;	//flags
	short aerator, castle, plants, treasure, tank;	//options
};

// Define an ASCII art "image"
struct cimage {
	short BG, FG;	// colours
	short rot13;	// rot13 flag
	unsigned short numlines;	// number of lines
	char *lines[50]; // up to a whole screen
};
typedef struct cimage CIMAGE;

// Define an object that refers to an image
struct cobject {
	short state;	// resting/moving/turning
	short dir;		// direction of fish
	short x, y;		// x, y location
	short priority;	// low = back, high = front
	short curpath;
	short BG, FG;	// colours (override cimage)
	short speed, count;
	short path[80][2]; // -1, -1 = end
	CIMAGE *image;
};
typedef struct cobject COBJECT;

// Define an area of the screen that does something
struct button {
	char hotkey;
	short x, y;
	short width, height;
	void (*function)();
};
typedef struct button BUTTON;

// Define stuff for fishes to say
#define DONTWAIT 0
#define WAIT 1
struct speeches {
	short numspeeches;
	short speechesleft;
	short probability;
	short said[30];
	char lines[30][2][60];
};
typedef struct speeches SPEECHES;

// All the speeches for the fishes.
SPEECHES fishspeeches[7] = {
/*
 "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@"}};
*/
// oynpx naq juvgr
{ 3, 0, 10, {0}, {
{"0Gurer nva'g ebbz va guvf urer svfugnax sbe gur ybg bs hf!",""},
{"0Lrrrr-unj!  Evqr 'rz, svful!",""},
{"1Ebyyva' ebyyva' ebyyva', xrrc gubfr svfuvrf ebyyva'", "Enjuvqr!"}
}},
// jvaqbjf
{ 2, 0, 10, {0}, {
{"0Pnyy Ovyy!",""},
{"0Nj zna, gur svfugnax'f penfurq ntnva.",""}
}},
// zngevk
{ 11, 0, 50, {0}, {
{"0Jung vf gur Zngevk?",""},
{"0Ab!  Gurl phg gur uneq yvar!",""},
{"0Sbyybj gur juvgr enoovg.",""},
{"0Lbh rire unir gung srryvat jurer lbh'er abg", "fher vs lbh'er njnxr be fgvyy qernzvat?"},
{"0Gurl'er jngpuvat hf.",""},
{"0Jung tbbq ner svaf vs lbh ner hanoyr gb fjvz?",""},
{"0Hasbeghangryl, ab bar pna or gbyq jung gur Zngevk vf...",""},
{"0Lbh gnxr gur oyhr svfu, gur fgbel raqf...", "Lbh gnxr gur erq svfu, lbh fgnl va Jbaqreynaq."},
{"0Evtug abj jr'er vafvqr n pbzchgre cebtenz?",""},
{"0Lbh guvax gung'f jngre lbh'er fjvzzvat va abj?",""},
{"0Gnax, V arrq na rkvg!",""}
}},
// urng
{ 2, 0, 10, {0}, {
{"0Vf vg ubg va urer, be vf vg whfg zr?",""},
{"0Bhg bs gur selvat cna, vagb gur sver...",""},
}},
// pbyq
{ 3, 0, 10, {0}, {
{"0Oee!",""},
{"0Ghea hc gur urng!",""},
{"0V'z pbyq.  V arrq n fjrngre.",""}
}},
// gernfher
{ 12, 0, 10, {0}, {
{"1Nee!  Jung or va gung gurer gernfher purfg?  Qbhoybbaf?", "Jnerm."},
{"0Fjno gur zvmmraznfg!",""},
{"0Syvz gur wvzwnz!",""},
{"0Ubvfg gur znvafnvy!",""},
{"0Jnyx gur cynax!",""},
{"0Neeeeee!!",""},
{"0Ninfg, lr urnegvrf!",""},
{"1Lbh svtug yvxr n qnvel snezre!", "Ubj nccebcevngr.  Lbh svtug yvxr n pbj."},
{"1Zl unaqxrepuvrs jvyy jvcr hc lbhe oybbq!", "Fb lbh tbg gung wbo nf n wnavgbe nsgre nyy."},
{"1Fbba lbh'yy or jrnevat zl fjbeq yvxr n fuvfu-xrono!", "Svefg lbh'q orggre fgbc jnivat vg yvxr n srngure qhfgre."},
{"1Abobql'f rire qenja oybbq sebz zr naq abobql rire jvyy!", "Lbh eha GUNG snfg?"},
{"1Zl jvfrfg rarzvrf eha njnl ng gur svefg fvtug bs zr!", "Rira ORSBER gurl fzryy lbhe oerngu?"}
}},
// erthyne
{ 23, 0, 100, {0}, {
{"0Fbzrguvat fzryyf svful nebhaq urer...",""},
{"1Tbg nal guerrf?", "Tb svfu."},
{"1Nalbar sbe fhfuv?", "Lbh svraq!"},
{"1Bar svfu, gjb svfu.", "Erq svfu, oyhr svfu."},
{"0Erzrzore...  Guerr unzf jvyy fheryl xvyy hf.",""},
{"0Fnyfn funex!",""},
{"0Uryyb pvgvmra!  Ner lbh trggvat rabhtu bkltra?",""},
{"0Lbhe zbgure jnf n thccl, naq lbhe sngure fzryg bs nytnr!",""},
{"0Nalbar jnag gb yvfgra gb fbzr Zbol?",""},
{"0V pnhtug zl svefg uhzna gbqnl!",""},
{"0Jurer'f Frnzna?",""},
{"0Nalbar tbg n ovplpyr V pna obeebj?",""},
{"0Pnecr qvrz!  Svfu bs gur qnl!",""},
{"0N zna znl svfu jvgu gur jbez gung ungu rng bs n","xvat, naq rng bs gur svfu gung ungu srq bs gung jbez."},
{"0V guvax V'yy tebj n tubgv.",""},
{"0Phevbhfvgl xvyyrq gur pngsvfu.",""},
{"0Gur anzr'f Cbaq.  Wnzrf Cbaq.",""},
{"0Lbh pna ghar n cvnab, ohg lbh pna'g ghan svfu.",""},
{"0Gur rneyl svfu trgf pnhtug ol gur jbez.",""},
{"1Zbfg bs gur Rnegu'f fhesnpr vf jngre...","Jr ehyr!"},
{"0Tvir n zna n svfu naq ur'yy rng sbe n qnl.","Grnpu n zna gb svfu, naq V'yy or naablrq jvgu lbh."},
{"0Jung qbrf n svfu unir gb qb gb trg n qevax nebhaq urer?",""},
{"0Lbh'yy or fyrrcvat jvgu gur svfurf ol fhaqbja!",""}
}}};

/*************************************************************************/
